@@ -1,6 +1,6 @@
 """A Python interface for interacting with OpenFOAM."""
 
-__version__ = "0.6.5"
+__version__ = "1.1.0"
 
 from ._cases import (
     AsyncFoamCase,
@@ -10,16 +10,15 @@ from ._cases import (
     FoamCaseBase,
     FoamCaseRunBase,
 )
-from ._files import FoamFieldFile, FoamFile, FoamFileBase
+from ._files import FoamFieldFile, FoamFile
 
 __all__ = [
     "AsyncFoamCase",
     "AsyncSlurmFoamCase",
     "CalledProcessError",
-    "FoamFile",
     "FoamCase",
     "FoamCaseBase",
     "FoamCaseRunBase",
     "FoamFieldFile",
-    "FoamFileBase",
+    "FoamFile",
 ]
